pub struct ScryptHasher {
pub params: ScryptParams,
}Expand description
A scrypt password hasher that bundles its own cost parameters.
Implements PasswordHash so it can be
used polymorphically with crate::verify_password.
Design note — params argument is ignored
The PasswordHash::hash_password
trait method accepts a params: &dyn PasswordHashParams argument, but this
implementation ignores it and uses self.params instead. Callers that
need different scrypt parameters should construct a new ScryptHasher
with the desired ScryptParams rather than passing a different
PasswordHashParams object.
Fields
params: ScryptParamsScrypt cost parameters.
Implementations
Sourceimpl ScryptHasher
impl ScryptHasher
Sourcepub fn new(params: ScryptParams) -> Result<Self, CryptoError>
pub fn new(params: ScryptParams) -> Result<Self, CryptoError>
Create a new hasher with explicit parameters.
Returns an error if the parameters are out of range.
Sourcepub fn new_checked(params: ScryptParams) -> Self
pub fn new_checked(params: ScryptParams) -> Self
Create a new hasher, panicking if params are invalid.
Prefer ScryptHasher::new in production code.
Sourcepub fn interactive() -> Self
pub fn interactive() -> Self
Interactive login preset.